@@ -1,7 +1,7 @@
 /* about.c - 2000/05/05 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -115,29 +115,35 @@ void Show_About_Window (void)
 
     /* Translation contributions */
     gchar *translations_thanks_text [][2]= {
-            {"    - Bastian Kleineidam ",      _("(German translation)")},
-            {"    - Adrian Bunk ",             _("(German translation)")},
-            {"    - Colin Marquardt ",         _("(German translation)")},
-            {"    - Philipp Thomas ",          _("(German translation)")},
-            {"    - Sergey Zhumatiy ",         _("(Russian translation)")},
-            {"    - Andrey Astafiev ",         _("(Russian translation)")},
-            {"    - Vincent van Adrighem ",    _("(Dutch translation)")},
-            {"    - Bjrn Olievier ",          _("(Dutch translation)")},
-            {"    - Patrik Israelsson ",       _("(Swedish translation)")},
-            {"    - Szel Miklos ",             _("(Hungarian translation)")},
-            {"    - Nagy Boldizsar ",          _("(Hungarian translation)")},
-            {"    - Cappelletti Lorenzo ",     _("(Italian translation)")},
-            {"    - Kostantino ",              _("(Italian translation)")},
-            {"    - Takeshi Aihana ",          _("(Japanese translation)")},
-            {"    - Olexander Kunytsa ",       _("(Ukrainian translation)")},
-            {"    - Cawko Xakep ",             _("(Ukrainian translation)")},
-            {"    - Milan Siebenburger ",      _("(Czech translation)")},
-            {"    - Jaime Serrano Cartagena ", _("(Spanish translation)")},
-            {"    - Maciej Kasprzyk ",         _("(Polish translation)")},
-            {"    - Pauliuc George ",          _("(Romanian translation)")},
-            {"    - Morten Brix Pedersen ",    _("(Danish translation)")},
+            {"    - Bastian Kleineidam ",           _("(German translation)")},
+            {"    - Adrian Bunk ",                  _("(German translation)")},
+            {"    - Colin Marquardt ",              _("(German translation)")},
+            {"    - Philipp Thomas ",               _("(German translation)")},
+            {"    - Sergey Zhumatiy ",              _("(Russian translation)")},
+            {"    - Andrey Astafiev ",              _("(Russian translation)")},
+            {"    - Vincent van Adrighem ",         _("(Dutch translation)")},
+            {"    - Bjrn Olievier ",               _("(Dutch translation)")},
+            {"    - Patrik Israelsson ",            _("(Swedish translation)")},
+            {"    - Szel Miklos ",                  _("(Hungarian translation)")},
+            {"    - Nagy Boldizsar ",               _("(Hungarian translation)")},
+            {"    - Cappelletti Lorenzo ",          _("(Italian translation)")},
+            {"    - Costantino ",                   _("(Italian translation)")},
+            {"    - Takeshi Aihana ",               _("(Japanese translation)")},
+            {"    - Olexander Kunytsa ",            _("(Ukrainian translation)")},
+            {"    - Cawko Xakep ",                  _("(Ukrainian translation)")},
+            {"    - Milan Siebenburger ",           _("(Czech translation)")},
+            {"    - Zbynek Mrkvicka ",              _("(Czech translation)")},
+            {"    - Jaime Serrano Cartagena ",      _("(Spanish translation)")},
+            {"    - Fernando M. Bueno Moreno ",     _("(Spanish translation)")},
+            {"    - Francisco Javier F. Serrador ", _("(Spanish translation)")},
+            {"    - Maciej Kasprzyk ",              _("(Polish translation)")},
+            {"    - Pauliuc George ",               _("(Romanian translation)")},
+            {"    - Morten Brix Pedersen ",         _("(Danish translation)")},
+            {"    - Apollon Oikonomopoulos ",       _("(Greek translation)")},
+            {"    - doutor zero ",                  _("(Brazilian Portuguese translation)")},
             {NULL,NULL}
             };
+
     /* General contributions */
     gchar *general_thanks_text = 
             "    - Daniel Drake (GTK2 port)\n"
@@ -170,6 +176,7 @@ void Show_About_Window (void)
             "    - Pavel Minayev\n"
             "    - Justus Schwartz\n"
             "    - Fredrik Noring\n"
+            "    - Guilherme Destefani\n"
             "";
 
 
