@@ -1,7 +1,7 @@
 /* bar.c - 2000/05/05 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -127,7 +127,21 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
     GtkWidget *toolbar;
     GtkWidget *toolbarwidget;
 
-    GtkActionEntry ActionEntries[] = {
+    /*
+     * Structure :
+     *  - name
+     *  - stock_id
+     *  - label
+     *  - accelerator
+     *  - tooltip
+     *  - callback
+     */
+    GtkActionEntry ActionEntries[] = 
+    {
+        
+        /*
+         * Main Menu Actions
+         */
         { MENU_FILE, NULL, _("_File") },
 
         { MENU_FILE_SORT_TAG,                 GTK_STOCK_SORT_ASCENDING,  _("Sort list by tag") },
@@ -203,13 +217,13 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
         { AM_INITIALIZE_TREE,          GTK_STOCK_REFRESH,      _("_Refresh Tree"),                 "<Control><Shift>R", _("_Refresh Tree"),                 G_CALLBACK(Browser_Tree_Rebuild) },
 
         { MENU_SCANNER,              NULL,           _("S_canner") },
-        { AM_SCANNER_FILL_TAG,       "easytag-scan", _("_Fill Tag(s) ..."),      NULL, _("Fill Tag(s) ..."),       G_CALLBACK(Scan_Use_Fill_Tag_Scanner) },
-        { AM_SCANNER_RENAME_FILE,    "easytag-scan", _("_Rename File(s) ..."),   NULL, _("Rename File(s) ..."),    G_CALLBACK(Scan_Use_Rename_File_Scanner) },
-        { AM_SCANNER_PROCESS_FIELDS, "easytag-scan", _("_Process Field(s) ..."), NULL, _("Process Fields(s) ..."), G_CALLBACK(Scan_Use_Process_Fields_Scanner) },
+        { AM_SCANNER_FILL_TAG,       "easytag-scan", _("_Fill Tag(s) ..."),                     NULL, _("Fill Tag(s) ..."),                 G_CALLBACK(Scan_Use_Fill_Tag_Scanner) },
+        { AM_SCANNER_RENAME_FILE,    "easytag-scan", _("_Rename File(s) and Directory ..."),    NULL, _("Rename File(s) and Directory ..."),G_CALLBACK(Scan_Use_Rename_File_Scanner) },
+        { AM_SCANNER_PROCESS_FIELDS, "easytag-scan", _("_Process Field(s) ..."),                NULL, _("Process Fields(s) ..."),           G_CALLBACK(Scan_Use_Process_Fields_Scanner) },
 
         { MENU_MISC,            NULL,              _("_Misc") },
         { AM_SEARCH_FILE,       GTK_STOCK_FIND,    _("S_earch File(s) ..."),         "<Alt>E", _("Search File(s)..."),           G_CALLBACK(Open_Search_File_Window) },
-        { AM_CDDB_SEARCH,       GTK_STOCK_CDROM,   _("_CDDB Search ..."),            NULL,     _("CDDB Search ..."),             G_CALLBACK(Open_Cddb_Window) },
+        { AM_CDDB_SEARCH,       GTK_STOCK_CDROM,   _("_CD Data Base Search ..."),    NULL,     _("CDDB Search ..."),             G_CALLBACK(Open_Cddb_Window) },
         { AM_FILENAME_FROM_TXT, GTK_STOCK_OPEN,    _("Load Filenames from TXT ..."), "<Alt>T", _("Load Filenames from TXT ..."), G_CALLBACK(Open_Load_Filename_Window) },
         { AM_WRITE_PLAYLIST,    GTK_STOCK_SAVE_AS, _("Write Playlist ..."),          "<Alt>W", _("Write Playlist ..."),          G_CALLBACK(Open_Write_Playlist_Window) },
         { AM_RUN_AUDIO_PLAYER,  "easytag-sound",   _("Run Audio Player"),            "<Alt>X", _("Run Audio Player"),            G_CALLBACK(Run_Audio_Player_Using_Selection) },
@@ -221,17 +235,25 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
         { MENU_HELP,            NULL,           _("_Help") },
         { AM_OPEN_ABOUT_WINDOW, GTK_STOCK_HELP, _("_About"), "<Alt>A", _("About"), G_CALLBACK(Show_About_Window) },
 
-        /* Following items are on toolbar but not on menu */
+
+        /*
+         * Following items are on toolbar but not on menu
+         */
         { AM_STOP, GTK_STOCK_STOP, _("Stop the current action"), NULL, _("Stop the current action"), G_CALLBACK(Action_Main_Stop_Button_Pressed) },
 
-        /* Popup menu's */
+
+        /*
+         * Popup menu's Actions
+         */
         { POPUP_FILE,            NULL,              _("_File Operations") },
         { POPUP_SUBMENU_SCANNER, "easytag-scan",    _("S_canner") },
-        { POPUP_DIR_RUN_AUDIO,   GTK_STOCK_EXECUTE, _("Run Audio Player"),           "<Alt>X", _("Run Audio Player"),           G_CALLBACK(Run_Audio_Player_Using_Directory) },
+        { POPUP_DIR_RUN_AUDIO,   GTK_STOCK_EXECUTE, _("Run Audio Player"),          "<Alt>X", _("Run Audio Player"),        G_CALLBACK(Run_Audio_Player_Using_Directory) },
+        { AM_CDDB_SEARCH_FILE,   GTK_STOCK_CDROM,   _("CDDB Search File(s)..."),    NULL,     _("CDDB Search File(s)..."),  G_CALLBACK(Cddb_Popup_Menu_Search_Selected_File) },
 
     };
 
-    GtkToggleActionEntry ToggleActionEntries[] = {
+    GtkToggleActionEntry ToggleActionEntries[] = 
+    {
         { AM_RECURSE,         GTK_STOCK_INDEX,        _("Browse _Sub-directories"),                         NULL, _("Browse _Sub-directories"),                          NULL,                                    FALSE },
         { AM_VIEWMODE_TOGGLE, "easytag-artist-album", _("Show tree browser / Display by Artist and Album"), NULL, _ ("Show tree browser / Display by Artist and Album"), G_CALLBACK(Action_Select_Browser_Style), FALSE },
     };
