@@ -132,6 +132,7 @@ const CharsetInfo charset_trans_array[] = {
 */
 };
 
+static GHashTable *encodings;
 
 
 
@@ -140,24 +141,155 @@ const CharsetInfo charset_trans_array[] = {
  *************/
 
 
-gchar *convert_string (const gchar *string, const gchar *from, const gchar *to)
+/* stolen from gnome-desktop-item.c */
+static gboolean
+check_locale (const char *locale)
+{
+    GIConv cd = g_iconv_open ("UTF-8", locale);
+    if ((GIConv)-1 == cd)
+        return FALSE;
+    g_iconv_close (cd);
+    return TRUE;
+}
+
+/* stolen from gnome-desktop-item.c */
+static void
+insert_locales (GHashTable *encodings, char *enc, ...)
+{
+    va_list args;
+    char *s;
+
+    va_start (args, enc);
+    for (;;) {
+        s = va_arg (args, char *);
+        if (s == NULL)
+            break;
+        g_hash_table_insert (encodings, s, enc);
+    }
+    va_end (args);
+}
+
+/* stolen from gnome-desktop-item.c */
+void
+Charset_Insert_Locales_Init (void)
+{
+/* make a standard conversion table from the desktop standard spec */
+    encodings = g_hash_table_new (g_str_hash, g_str_equal);
+
+    /* "C" is plain ascii */
+    insert_locales (encodings, "ASCII", "C", NULL);
+
+    insert_locales (encodings, "ARMSCII-8", "by", NULL);
+    insert_locales (encodings, "BIG5", "zh_TW", NULL);
+    insert_locales (encodings, "CP1251", "be", "bg", NULL);
+    if (check_locale ("EUC-CN")) {
+        insert_locales (encodings, "EUC-CN", "zh_CN", NULL);
+    } else {
+        insert_locales (encodings, "GB2312", "zh_CN", NULL);
+    }
+    insert_locales (encodings, "EUC-JP", "ja", NULL);
+    insert_locales (encodings, "UHC", "ko", NULL);
+    /*insert_locales (encodings, "GEORGIAN-ACADEMY", NULL);*/
+    insert_locales (encodings, "GEORGIAN-PS", "ka", NULL);
+    insert_locales (encodings, "ISO-8859-1", "br", "ca", "da", "de", "en", "es", "eu", "fi", "fr", "gl", "it", "nl", "wa", "no", "pt", "pt", "sv", NULL);
+    insert_locales (encodings, "ISO-8859-2", "cs", "hr", "hu", "pl", "ro", "sk", "sl", "sq", "sr", NULL);
+    insert_locales (encodings, "ISO-8859-3", "eo", NULL);
+    insert_locales (encodings, "ISO-8859-5", "mk", "sp", NULL);
+    insert_locales (encodings, "ISO-8859-7", "el", NULL);
+    insert_locales (encodings, "ISO-8859-9", "tr", NULL);
+    insert_locales (encodings, "ISO-8859-13", "lt", "lv", "mi", NULL);
+    insert_locales (encodings, "ISO-8859-14", "ga", "cy", NULL);
+    insert_locales (encodings, "ISO-8859-15", "et", NULL);
+    insert_locales (encodings, "KOI8-R", "ru", NULL);
+    insert_locales (encodings, "KOI8-U", "uk", NULL);
+    if (check_locale ("TCVN-5712")) {
+        insert_locales (encodings, "TCVN-5712", "vi", NULL);
+    } else {
+        insert_locales (encodings, "TCVN", "vi", NULL);
+    }
+    insert_locales (encodings, "TIS-620", "th", NULL);
+    /*insert_locales (encodings, "VISCII", NULL);*/
+}
+
+void
+Charset_Insert_Locales_Destroy (void)
+{
+    g_hash_table_destroy (encodings);
+}
+
+/* stolen from gnome-desktop-item.c */
+static const char *
+get_encoding_from_locale (const char *locale)
+{
+    char lang[3];
+    const char *encoding;
+
+    if (locale == NULL)
+        return NULL;
+
+    /* if locale includes encoding (that isn't UTF-8), use it */
+    encoding = strchr (locale, '.');
+    if (encoding != NULL && strncmp (encoding, ".UTF-8", 6)) {
+        return encoding+1;
+    }
+
+    /* first try the entire locale (at this point ll_CC) */
+    encoding = g_hash_table_lookup (encodings, locale);
+    if (encoding != NULL)
+        return encoding;
+
+    /* Try just the language */
+    strncpy (lang, locale, 2);
+    lang[2] = '\0';
+    return g_hash_table_lookup (encodings, lang);
+}
+
+/*
+char *
+rb_unicodify (const char *str)
+{
+    char *ret = NULL;
+    const char *char_encoding;
+
+    // Try validating it as UTF-8 first
+    if (g_utf8_validate (str, -1, NULL))
+        return g_strdup (str);
+
+    // Failing that, try the legacy encoding associated with the locale.
+    char_encoding = get_encoding_from_locale (getenv ("LANG"));
+    if (char_encoding == NULL)
+        ret = NULL;
+    else
+        ret = g_convert (str, -1, "UTF-8", char_encoding,
+                 NULL, NULL, NULL);
+    // Failing that, try ISO-8859-1
+    if (!ret)
+        ret = g_convert (str, -1, "UTF-8", "ISO-8859-1",
+                 NULL, NULL, NULL);
+
+    return ret;
+}*/
+
+
+
+
+
+gchar *convert_string (const gchar *string, const gchar *from_codeset, const gchar *to_codeset)
 {
     gchar *output;
     GError *error = NULL;
 
     if (!string)
         return NULL;
-
-    output = g_convert(string, -1, to, from, NULL, NULL, &error);
-
-    //g_message("converting %s from %s to %s", string, from, to);
+    
+    output = g_convert(string, -1, to_codeset, from_codeset, NULL, NULL, &error);
 
     if (output == NULL)
     {
         gchar *escaped_str = g_strescape(string, NULL);
         g_warning("convert_string(): Failed conversion from charset '%s' to '%s'. "
                   "String '%s'. Errcode %d (%s).\n",
-                  from, to, escaped_str, error->code, error->message);
+                  from_codeset, to_codeset, escaped_str, error->code, error->message);
         g_free(escaped_str);
         g_error_free(error);
         return g_strdup(string);
@@ -239,12 +371,13 @@ gchar *convert_from_utf8 (const char *string)
 /*
  * Conversion with ISO-8859-1 for ID3v2.3 tags (current_charset <===> ISO-8859-1)
  */
+/***
 char *convert_to_iso88591 (const char *string)
 {
     const gchar *charset;
     g_get_charset(&charset);
 
-    /* No conversion needed */
+    // No conversion needed
     if (strcmp(charset, "ANSI_X3.4-1968") == 0)
         return g_strdup(string);
 
@@ -256,18 +389,20 @@ char *convert_from_iso88591 (const char *string)
     const gchar *charset;
     g_get_charset(&charset);
 
-    /* No conversion needed */
+    // No conversion needed
     if (strcmp(charset, "ANSI_X3.4-1968") == 0)
         return g_strdup(string);
 
     return convert_string(string, "ISO-8859-1", charset);
 }
+***/
 
 
 
 /*
  * Conversion with "this_charset" for ID3v2.3 tags (current_charset <===> this_charset)
  */
+/***
 // Convert from the locale charset to 'this_charset'
 char *convert_to_this_charset (const char *string, char *this_charset)
 {
@@ -285,50 +420,62 @@ char *convert_from_this_charset (const char *string, char *this_charset)
 
     return convert_string(string, this_charset, charset);
 }
-
-
-
-/*
- * Conversion functions using default parameters set by user in the preference window. (USER_CHARACTER_SET <===> FILE_CHARACTER_SET)
- */
-char *convert_from_user_to_file (const char *string)
-{
-    char *file_charset = FILE_CHARACTER_SET;
-    char *user_charset = USER_CHARACTER_SET;
-
-    return convert_string(string,user_charset,file_charset);
-}
-
-char *convert_from_file_to_user (const char *string)
-{
-    char *file_charset = FILE_CHARACTER_SET;
-    char *user_charset = USER_CHARACTER_SET;
-
-    return convert_string(string,file_charset,user_charset);
-}
+***/
 
 
 /*
- * Functions to translate filename to/from UTF-8
+ * Functions to translate filename to UTF-8
  * Based around the ideas under "File Name Encodings" at
  *    http://developer.gnome.org/doc/API/2.0/glib/glib-Character-Set-Conversion.html
  */
+/*
+ * Convert a string from the filename system encoding to UTF-8.
+ *  - conversion OK : returns the UTF-8 string (new allocated)
+ *  - conversion KO : tries others encodings else returns an 'escaped' string
+ */
 gchar *filename_to_display (const gchar *string)
 {
     GError *error = NULL;
-    gchar *temp = g_filename_to_utf8(string, -1, NULL, NULL, &error);
+    gchar *temp;
+    
+    if (!string)
+        return NULL;
+
+    temp = g_filename_to_utf8(string, -1, NULL, NULL, &error);
     if (!temp)
     {
         // Conversion KO!
-        gchar *escaped_str = g_strescape(string, NULL);
-        g_warning(_("The filename '%s' couldn't be converted to UTF-8. "
-                    "(Try setting the environment variable G_FILENAME_ENCODING): %s\n"),
-                    escaped_str, error->message ? error->message : _("Invalid UTF-8"));
-        //g_free(escaped_str);
-        g_clear_error(&error);
+        const gchar *char_encoding;
+        gchar *ret;
+        
+        // Try the legacy encoding associated with the locale.
+        char_encoding = get_encoding_from_locale(getenv("LANG"));
+        if (char_encoding)
+        {
+            ret = g_convert(string, -1, "UTF-8", char_encoding, NULL, NULL, NULL);
+        }else
+        {
+            // Failing that, try ISO-8859-1
+            ret = g_convert(string, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
+        }
 
-        //return g_strdup(string);
-        return g_strdup(escaped_str); // Don't free escaped_str if used!
+        if (!ret)
+        {
+            gchar *escaped_str = g_strescape(string, NULL);
+            g_warning(_("The filename '%s' couldn't be converted into UTF-8 (%s).\n"
+                        "To fix : this file name musn't be in UTF-8 encoding. So "
+                        "specify the right encoding for file name in the "
+                        "G_FILENAME_ENCODING environment variable (for example : "
+                        "export G_FILENAME_ENCODING=ISO-8859-1).\n"),
+                        escaped_str, error->message ? error->message : _("Invalid UTF-8"));
+            g_clear_error(&error);
+    
+            return escaped_str;
+        }else
+        {
+            return ret;
+        }
+        
     }else
     {
         // Conversion OK
@@ -336,14 +483,24 @@ gchar *filename_to_display (const gchar *string)
     }
 }
 
-gchar *filename_from_display (const gchar* string)
+/*
+ * Convert a string from UTF-8 to the filename system encoding.
+ *  - conversion OK : returns the string in filename system encoding (new allocated)
+ *  - conversion KO : display error message + returns nothing!
+ */
+gchar *filename_from_display (const gchar *string)
 {
-    gchar *temp = g_filename_from_utf8(string, -1, NULL, NULL, NULL);
+    gchar *temp;
+
+    if (!string) return NULL;
+    
+    temp = g_filename_from_utf8(string, -1, NULL, NULL, NULL);
     if (!temp)
     {
         // Conversion KO!
         gchar *escaped_str = g_strescape(string, NULL);
-        g_print("WARNING: Could not convert string %s into filename encoding\n", escaped_str);
+        g_warning(_("The UTF-8 string '%s' couldn't be converted into filename "
+                    "encoding\n"), escaped_str);
         g_free(escaped_str);
     }
 
@@ -437,12 +594,14 @@ gboolean test_conversion_charset (const gchar *from, const gchar *to)
             g_print("Conversion error from '%s' to '%s' (unknown : %d)\n",from,to,error->code);
         }
         
-        if (error) g_error_free(error);
+        if (error)
+            g_error_free(error);
         return FALSE;
     } else
     {
         // No error
-        if (error) g_error_free(error);
+        if (error)
+            g_error_free(error);
         g_free(temp);
         return TRUE;
     }
