@@ -1,7 +1,7 @@
 /* et_core.h - 2001/10/21 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,11 +33,17 @@
  ***************/
 
 #ifndef MAX
-#    define MAX(a,b) ((a) > (b) ? (a) : (b))
+#    define MAX(a,b)      ((a) > (b) ? (a) : (b))
 #endif
 
 #ifndef MIN
-#    define MIN(a,b) ((a) < (b) ? (a) : (b))
+#    define MIN(a,b)      ((a) < (b) ? (a) : (b))
+#endif
+#ifndef MIN3
+#    define MIN3(x,y,z)   (MIN(x,y) < (z) ? MIN(x,y) : (z))
+#endif
+#ifndef MIN4
+#    define MIN4(x,y,z,w) (MIN3(x,y,z) < (w) ? MIN3(x,y,z) : (w))
 #endif
 
 
@@ -171,6 +177,7 @@ struct _File_Tag
     gchar *title;          /* Title of track */
     gchar *artist;         /* Artist name */
     gchar *album;          /* Album name */
+    gchar *disc_number;    /* Disc number */
     gchar *year;           /* Year of track */
     gchar *track;          /* Position of track in the album */
     gchar *track_total;    /* The number of tracks for the album (ex: 12/20) */
@@ -382,10 +389,11 @@ gboolean ET_History_File_List_Has_Redo_Data (void);
 gboolean ET_Manage_Changes_Of_File_Data          (ET_File *ETFile, File_Name *FileName, File_Tag *FileTag);
 void     ET_Mark_File_Name_As_Saved              (ET_File *ETFile);
 void     ET_Update_Directory_Name_Into_File_List (gchar* last_path, gchar *new_path);
-gboolean ET_File_Name_Convert_Character          (gchar *filename);
+gboolean ET_File_Name_Convert_Character          (gchar *filename_utf8);
 gchar   *ET_File_Name_Format_Extension           (ET_File *ETFile);
 gchar   *ET_File_Name_Generate                   (ET_File *ETFile, gchar *new_file_name);
-guint    ET_Get_Number_Of_Files_In_Directory     (gchar *path);
+guint    ET_Get_Number_Of_Files_In_Directory     (gchar *path_utf8);
+gchar   *ET_Utf8_Validate_Full_String            (gchar *string_to_validate);
 
 void ET_Sort_Displayed_File_List                          (ET_Sorting_Type Sorting_Type);
 void ET_Sort_Displayed_File_List_And_Update_UI            (ET_Sorting_Type Sorting_Type);
