@@ -1,7 +1,7 @@
 /* flac_tag.c - 2003/12/27 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2001-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2001-2003  Jerome Couderc <easytag@gmail.com>
  *  Copyright (C) 2003       Pavel Minayev <thalion@front.ru>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -76,6 +76,7 @@
  * Prototypes *
  **************/
 gboolean Flac_Tag_Write_File (FILE *file_in, gchar *filename_in, vcedit_state *state);
+gchar   *Flac_Tag_Validate_Utf8_Field (gchar *string);
 
 
 /*************
@@ -94,6 +95,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     FLAC__StreamMetadata_VorbisComment          *vc;
     FLAC__StreamMetadata_VorbisComment_Entry    *field;
     gchar                                       *field_value;
+    gchar                                       *field_value_tmp;
     gchar                                       *string = NULL;
     gint                                        field_num;
     gint                                        field_len;
@@ -140,6 +142,16 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     vc_block = FLAC__metadata_simple_iterator_get_block(iter);
     vc = &vc_block->data.vorbis_comment;
 
+    /* Get vendor string */
+    /*{
+        FLAC__StreamMetadata_VorbisComment_Entry vce;
+        vce = vc->vendor_string;
+        g_print("File %s : \n",filename);
+        g_print(" - FLAC File vendor string : '%s'\n",g_strndup(vce.entry,vce.length));
+        g_print(" - FLAC Lib vendor string  : '%s'\n",FLAC__VENDOR_STRING);
+    }*/
+
+
     /*********
      * Title *
      *********/
@@ -149,18 +161,22 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         /* Extract field value */
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
-
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            if (FileTag->title==NULL)
-                FileTag->title = g_strdup(field_value);
-            else
-                FileTag->title = g_strconcat(FileTag->title,MULTIFIELD_SEPARATOR,field_value,NULL);
-            g_free(field_value);
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                if (FileTag->title==NULL)
+                    FileTag->title = g_strdup(field_value);
+                else
+                    FileTag->title = g_strconcat(FileTag->title,MULTIFIELD_SEPARATOR,field_value,NULL);
+            }
         }
+        g_free(field_value);
     }
 
     /**********
@@ -173,15 +189,20 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            if (FileTag->artist==NULL)
-                FileTag->artist = g_strdup(field_value);
-            else
-                FileTag->artist = g_strconcat(FileTag->artist,MULTIFIELD_SEPARATOR,field_value,NULL);
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                if (FileTag->artist==NULL)
+                    FileTag->artist = g_strdup(field_value);
+                else
+                    FileTag->artist = g_strconcat(FileTag->artist,MULTIFIELD_SEPARATOR,field_value,NULL);
+            }
             g_free(field_value);
         }
     }
@@ -196,19 +217,47 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            if (FileTag->album==NULL)
-                FileTag->album = g_strdup(field_value);
-            else
-                FileTag->album = g_strconcat(FileTag->album,MULTIFIELD_SEPARATOR,field_value,NULL);
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                if (FileTag->album==NULL)
+                    FileTag->album = g_strdup(field_value);
+                else
+                    FileTag->album = g_strconcat(FileTag->album,MULTIFIELD_SEPARATOR,field_value,NULL);
+            }
             g_free(field_value);
         }
     }
 
+    /***************
+     * Disc Number *
+     ***************/
+    if ( (field_num = FLAC__metadata_object_vorbiscomment_find_entry_from(vc_block,0,"DISCNUMBER")) >= 0 )
+    {
+        /* Extract field value */
+        field = &vc->comments[field_num];
+        field_value = memchr(field->entry, '=', field->length);
+
+        if (field_value)
+        {
+            field_value++;
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                FileTag->year = field_value;
+            }
+        }
+    }
+
     /********
      * Year *
      ********/
@@ -218,12 +267,17 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            FileTag->year = field_value;
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                FileTag->year = field_value;
+            }
         }
     }
 
@@ -236,17 +290,22 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            if (NUMBER_TRACK_FORMATED)
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
             {
-                FileTag->track_total = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(field_value));
-            }else
-            {
-                FileTag->track_total = g_strdup(field_value);
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                if (NUMBER_TRACK_FORMATED)
+                {
+                    FileTag->track_total = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(field_value));
+                }else
+                {
+                    FileTag->track_total = g_strdup(field_value);
+                }
             }
             g_free(field_value);
         }
@@ -259,29 +318,34 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            string = g_utf8_strchr(field_value, -1, '/');
-            if (NUMBER_TRACK_FORMATED)
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
             {
-                // If track_total not filled before, try now...
-                if (string && !FileTag->track_total)
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                string = g_utf8_strchr(field_value, -1, '/');
+                if (NUMBER_TRACK_FORMATED)
                 {
-                    FileTag->track_total = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(string+1));
-                    *string = '\0';
-                }
-                FileTag->track = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(field_value));
-            }else
-            {
-                if (string && !FileTag->track_total)
+                    // If track_total not filled before, try now...
+                    if (string && !FileTag->track_total)
+                    {
+                        FileTag->track_total = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(string+1));
+                        *string = '\0';
+                    }
+                    FileTag->track = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(field_value));
+                }else
                 {
-                    FileTag->track_total = g_strdup(string+1);
-                    *string = '\0';
+                    if (string && !FileTag->track_total)
+                    {
+                        FileTag->track_total = g_strdup(string+1);
+                        *string = '\0';
+                    }
+                    FileTag->track = g_strdup(field_value);
                 }
-                FileTag->track = g_strdup(field_value);
             }
             g_free(field_value);
         }
@@ -297,15 +361,20 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            if (FileTag->genre==NULL)
-                FileTag->genre = g_strdup(field_value);
-            else
-                FileTag->genre = g_strconcat(FileTag->genre,MULTIFIELD_SEPARATOR,field_value,NULL);
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                if (FileTag->genre==NULL)
+                    FileTag->genre = g_strdup(field_value);
+                else
+                    FileTag->genre = g_strconcat(FileTag->genre,MULTIFIELD_SEPARATOR,field_value,NULL);
+            }
             g_free(field_value);
         }                
     }
@@ -320,15 +389,20 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            if (FileTag->comment==NULL)
-                FileTag->comment = g_strdup(field_value);
-            else
-                FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,field_value,NULL);
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                if (FileTag->comment==NULL)
+                    FileTag->comment = g_strdup(field_value);
+                else
+                    FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,field_value,NULL);
+            }
             g_free(field_value);
         }                
     }
@@ -343,15 +417,20 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            if (FileTag->composer==NULL)
-                FileTag->composer = g_strdup(field_value);
-            else
-                FileTag->composer = g_strconcat(FileTag->composer,MULTIFIELD_SEPARATOR,field_value,NULL);
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                if (FileTag->composer==NULL)
+                    FileTag->composer = g_strdup(field_value);
+                else
+                    FileTag->composer = g_strconcat(FileTag->composer,MULTIFIELD_SEPARATOR,field_value,NULL);
+            }
             g_free(field_value);
         }
     }
@@ -366,15 +445,20 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            if (FileTag->orig_artist==NULL)
-                FileTag->orig_artist = g_strdup(field_value);
-            else
-                FileTag->orig_artist = g_strconcat(FileTag->orig_artist,MULTIFIELD_SEPARATOR,field_value,NULL);
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                if (FileTag->orig_artist==NULL)
+                    FileTag->orig_artist = g_strdup(field_value);
+                else
+                    FileTag->orig_artist = g_strconcat(FileTag->orig_artist,MULTIFIELD_SEPARATOR,field_value,NULL);
+            }
             g_free(field_value);
         }
     }
@@ -389,15 +473,20 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            if (FileTag->copyright==NULL)
-                FileTag->copyright = g_strdup(field_value);
-            else
-                FileTag->copyright = g_strconcat(FileTag->copyright,MULTIFIELD_SEPARATOR,field_value,NULL);
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                if (FileTag->copyright==NULL)
+                    FileTag->copyright = g_strdup(field_value);
+                else
+                    FileTag->copyright = g_strconcat(FileTag->copyright,MULTIFIELD_SEPARATOR,field_value,NULL);
+            }
             g_free(field_value);
         }
     }
@@ -412,15 +501,20 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            if (FileTag->url==NULL)
-                FileTag->url = g_strdup(field_value);
-            else
-                FileTag->url = g_strconcat(FileTag->url,MULTIFIELD_SEPARATOR,field_value,NULL);
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                if (FileTag->url==NULL)
+                    FileTag->url = g_strdup(field_value);
+                else
+                    FileTag->url = g_strconcat(FileTag->url,MULTIFIELD_SEPARATOR,field_value,NULL);
+            }
             g_free(field_value);
         }
     }
@@ -435,15 +529,20 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
 
-        if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+        if (field_value)
         {
             field_value++;
-            field_len = field->length - (field_value - (gchar*) field->entry);
-            field_value = g_strndup(field_value, field_len);
-            if (FileTag->encoded_by==NULL)
-                FileTag->encoded_by = g_strdup(field_value);
-            else
-                FileTag->encoded_by = g_strconcat(FileTag->encoded_by,MULTIFIELD_SEPARATOR,field_value,NULL);
+            if ( field_value && g_utf8_strlen(field_value, -1) > 0 )
+            {
+                field_len = field->length - (field_value - (gchar*) field->entry);
+                field_value_tmp = g_strndup(field_value, field_len);
+                field_value = Flac_Tag_Validate_Utf8_Field(field_value_tmp);
+                g_free(field_value_tmp);
+                if (FileTag->encoded_by==NULL)
+                    FileTag->encoded_by = g_strdup(field_value);
+                else
+                    FileTag->encoded_by = g_strconcat(FileTag->encoded_by,MULTIFIELD_SEPARATOR,field_value,NULL);
+            }
             g_free(field_value);
         }
     }
@@ -458,6 +557,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         if ( strncasecmp(field->entry,"TITLE=",       MIN(6,  field->length)) != 0
           && strncasecmp(field->entry,"ARTIST=",      MIN(7,  field->length)) != 0
           && strncasecmp(field->entry,"ALBUM=",       MIN(6,  field->length)) != 0
+          && strncasecmp(field->entry,"DISCNUMBER=",  MIN(11, field->length)) != 0
           && strncasecmp(field->entry,"DATE=",        MIN(5,  field->length)) != 0
           && strncasecmp(field->entry,"TRACKNUMBER=", MIN(12, field->length)) != 0
           && strncasecmp(field->entry,"GENRE=",       MIN(6,  field->length)) != 0
@@ -480,6 +580,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     if ( FileTag->title       == NULL
       && FileTag->artist      == NULL
       && FileTag->album       == NULL
+      && FileTag->disc_number == NULL
       && FileTag->year        == NULL
       && FileTag->track       == NULL
       && FileTag->track_total == NULL
@@ -497,6 +598,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         if ( FileTag->title       != NULL
           || FileTag->artist      != NULL
           || FileTag->album       != NULL
+          || FileTag->disc_number != NULL
           || FileTag->year        != NULL
           || FileTag->track       != NULL
           || FileTag->track_total != NULL
@@ -522,13 +624,18 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
 {
     File_Tag                                 *FileTag;
     gchar                                    *filename_utf8, *filename;
-    gchar                                    *basename;
+    gchar                                    *basename_utf8;
     FLAC__Metadata_SimpleIterator            *iter;
     FLAC__StreamMetadata                     *vc_block;
     FLAC__StreamMetadata_VorbisComment_Entry field;
     FLAC__bool                               write_ok;
     gchar                                    *string;
     GList                                    *list;
+    // To get original vendor string
+    FLAC__StreamMetadata                     *vc_block_svg = NULL;
+    FLAC__StreamMetadata_VorbisComment       *vc_svg;
+    FLAC__StreamMetadata_VorbisComment_Entry field_svg;
+    gboolean                                 vc_found_svg = TRUE;
 
 
     if (!ETFile || !ETFile->FileTag)
@@ -558,8 +665,33 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
         return FALSE;
     }
 
-    vc_block = FLAC__metadata_object_new(FLAC__METADATA_TYPE_VORBIS_COMMENT);
+    /* Find the VORBIS_COMMENT block to get original vendor string */
+    while ( FLAC__metadata_simple_iterator_get_block_type(iter) != FLAC__METADATA_TYPE_VORBIS_COMMENT )
+    {
+        if ( !FLAC__metadata_simple_iterator_next(iter) )
+        {
+            /* End of metadata: comment block not found, nothing to read */
+            vc_found_svg = FALSE;
+            break;
+        }
+    }
+    if (vc_found_svg)
+    {
+        /* Get comments from block */
+        vc_block_svg = FLAC__metadata_simple_iterator_get_block(iter);
+        vc_svg = &vc_block_svg->data.vorbis_comment;
+        /* Get original vendor string */
+        field_svg = vc_svg->vendor_string;
+    }
 
+
+    vc_block = FLAC__metadata_object_new(FLAC__METADATA_TYPE_VORBIS_COMMENT);
+    
+    /* Set the original vendor string else it is version of library */
+    if (vc_found_svg)
+        FLAC__metadata_object_vorbiscomment_set_vendor_string(vc_block, field_svg, true);
+    
+    
     /*********
      * Title *
      *********/
@@ -596,6 +728,18 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
         g_free(string);
     }
 
+    /***************
+     * Disc Number *
+     ***************/
+    if ( FileTag->disc_number )
+    {
+        string  = g_strconcat("DISCNUMBER=",FileTag->disc_number,NULL);
+        field.entry = string;
+        field.length = strlen(string);
+        FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
+        g_free(string);
+    }
+
     /********
      * Year *
      ********/
@@ -760,13 +904,15 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
         return FALSE;
     }else
     {
-        basename = g_path_get_basename(filename_utf8);
-        g_print(_("Written tag of '%s'\n"),basename);
-        g_free(basename);
+        basename_utf8 = g_path_get_basename(filename_utf8);
+        g_print(_("Written tag of '%s'\n"),basename_utf8);
+        g_free(basename_utf8);
     }
 
     FLAC__metadata_simple_iterator_delete(iter);
     FLAC__metadata_object_delete(vc_block);
+    if (vc_found_svg)
+        FLAC__metadata_object_delete(vc_block_svg);
 
     /*
      * Write also the ID3 tags (ID3v1 and/or ID3v2) if wanted (as needed by some players)
@@ -796,4 +942,24 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
 }
 
 
+/*
+ * Check if passed a valid UTF-8 string in parameter.
+ * Else, the tag was probably encoded to ISO-8859-15 (by using for example
+ * "metaflac --no-utf8-convert ...") so we convert it from ISO-8859-1 to UTF-8.
+ */
+gchar *Flac_Tag_Validate_Utf8_Field (gchar *string)
+{
+    if ( !g_utf8_validate(string, -1, NULL) )
+    {
+        // Returns a native ISO-8859-15 string to UTF-8
+        return convert_string(string, "ISO-8859-1", "UTF-8");
+    }else
+    {
+        // Returns a native UTF-8 string
+        return g_strdup(string);
+    }
+    
+}
+
+
 #endif /* ENABLE_FLAC */
