@@ -1,7 +1,7 @@
 /* monkeyaudio_header.c */
 /*
  *  EasyTAG - Tag editor for MP3, Ogg Vorbis and MPC files
- *  Copyright (C) 2001-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2001-2003  Jerome Couderc <easytag@gmail.com>
  *  Copyright (C) 2002-2003  Artur Polaczyski <artii@o2.pl>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -46,9 +46,10 @@ gboolean Mac_Header_Read_File_Info(gchar *filename, ET_File_Info *ETFileInfo)
 {
     StreamInfoMac Info;
 
-    if (info_mac_read(filename, &Info)) {
+    if (info_mac_read(filename, &Info))
+    {
         gchar *filename_utf8 = filename_to_display(filename);
-        fprintf(stderr,"File \"%s\" not found\n", filename_utf8);
+        fprintf(stderr,"MAC header not found for file '%s'\n", filename_utf8);
         g_free(filename_utf8);
         return FALSE;
     }
