@@ -1,7 +1,7 @@
 /* ogg_tag.c - 2001/11/08 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2001-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2001-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -217,6 +217,12 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         }
     }
 
+    /*******************************
+     * Disc Number (Part of a Set) *
+     *******************************/
+    if ( (string = vorbis_comment_query(vc,"DISCNUMBER",0)) != NULL && g_utf8_strlen(string, -1) > 0 )
+        FileTag->disc_number = g_strdup(string);
+
     /********
      * Year *
      ********/
@@ -286,7 +292,8 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 FileTag->comment = g_strdup(string);
             else
                 FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,string,NULL);
-            if (string1 && g_utf8_strlen(string1, -1) > 0) g_free(string1);
+            if (string1 && g_utf8_strlen(string1, -1) > 0)
+                g_free(string1);
         }else if ( string1 && g_utf8_strlen(string1, -1) > 0 ) // Contains comment to Xmms format only
         {
             if (FileTag->comment==NULL)
@@ -382,6 +389,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         if ( strncasecmp(vc->user_comments[i],"TITLE=",       6) != 0
           && strncasecmp(vc->user_comments[i],"ARTIST=",      7) != 0
           && strncasecmp(vc->user_comments[i],"ALBUM=",       6) != 0
+          && strncasecmp(vc->user_comments[i],"DISCNUMBER=", 11) != 0
           && strncasecmp(vc->user_comments[i],"DATE=",        5) != 0
           && strncasecmp(vc->user_comments[i],"TRACKNUMBER=",12) != 0
           && strncasecmp(vc->user_comments[i],"GENRE=",       6) != 0
@@ -411,7 +419,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
     File_Tag       *FileTag;
     gchar          *filename;
     gchar          *filename_utf8;
-    gchar          *basename;
+    gchar          *basename_utf8;
     FILE           *file_in;
     vcedit_state   *state;
     vorbis_comment *vc;
@@ -422,7 +430,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
         return FALSE;
 
     FileTag       = (File_Tag *)ETFile->FileTag->data;
-    filename = ((File_Name *)ETFile->FileNameCur->data)->value;
+    filename      = ((File_Name *)ETFile->FileNameCur->data)->value;
     filename_utf8 = filename_to_display(filename);
     ogg_error_msg = NULL;
 
@@ -512,6 +520,16 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
         g_free(string);
     }
 
+    /***************
+     * Disc Number *
+     ***************/
+    if ( FileTag->disc_number )
+    {
+        string = g_strconcat("DISCNUMBER=",FileTag->disc_number,NULL);
+        vorbis_comment_add(vc,string);
+        g_free(string);
+    }
+
     /********
      * Year *
      ********/
@@ -640,9 +658,9 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
         return FALSE;
     }else
     {
-        basename = g_path_get_basename(filename_utf8);
-        g_print(_("Written tag of '%s'\n"),basename);
-        g_free(basename);
+        basename_utf8 = g_path_get_basename(filename_utf8);
+        g_print(_("Written tag of '%s'\n"),basename_utf8);
+        g_free(basename_utf8);
     }
 
     vcedit_clear(state);
