@@ -1,7 +1,7 @@
 /* prefs.h - 2000/05/06 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -75,6 +75,7 @@ GtkWidget *ReplaceIllegalCharactersInFilename;
 GtkWidget *FilenameExtensionNoChange;
 GtkWidget *FilenameExtensionLowerCase;
 GtkWidget *FilenameExtensionUpperCase;
+GtkWidget *PreserveModificationTime;
 GtkWidget *DateAutoCompletion;
 GtkWidget *NumberTrackFormated;
 GtkWidget *NumberTrackFormatedSpinButton;
@@ -83,8 +84,8 @@ GtkWidget *SortingFileCombo;
 GtkWidget *SortingFileCaseSensitive;
 GtkWidget *UseISO88591CharacterSetTranslation;
 GtkWidget *UseCharacterSetTranslation;
-GtkWidget *FileCharacterSetCombo;
-GtkWidget *UserCharacterSetCombo;
+GtkWidget *FileReadingCharacterSetCombo;
+GtkWidget *FileWritingCharacterSetCombo;
 
 GtkWidget *MessageBoxPositionNone;
 GtkWidget *MessageBoxPositionCenter;
