@@ -1,7 +1,7 @@
 /* scan.h - 2000/06/16 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,7 +32,8 @@ GtkWidget *ScannerWindow;
 GtkWidget *SWScanButton;    // To enable/disable it in easytag.c
 
 
-enum {
+enum
+{
     SCANNER_FILL_TAG = 0,
     SCANNER_RENAME_FILE,
     SCANNER_PROCESS_FIELDS
