@@ -1,7 +1,7 @@
 /* config.c - 2000/06/21 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -131,6 +131,7 @@ tConfigVariable Config_Variables[] =
     {"filename_extension_lower_case",        CV_TYPE_BOOL,    &FILENAME_EXTENSION_LOWER_CASE        },
     {"filename_extension_upper_case",        CV_TYPE_BOOL,    &FILENAME_EXTENSION_UPPER_CASE        },
     {"filename_extension_no_change",         CV_TYPE_BOOL,    &FILENAME_EXTENSION_NO_CHANGE         },
+    {"preserve_modification_time",           CV_TYPE_BOOL,    &PRESERVE_MODIFICATION_TIME         },
     {"date_auto_completion",                 CV_TYPE_BOOL,    &DATE_AUTO_COMPLETION                 },
     {"number_track_formated",                CV_TYPE_BOOL,    &NUMBER_TRACK_FORMATED                },
     {"number_track_formated_spin_button",    CV_TYPE_INT,     &NUMBER_TRACK_FORMATED_SPIN_BUTTON    },
@@ -140,8 +141,8 @@ tConfigVariable Config_Variables[] =
 
     {"use_iso_8859_1_character_set_translation",CV_TYPE_BOOL,  &USE_ISO_8859_1_CHARACTER_SET_TRANSLATION},
     {"use_character_set_translation",           CV_TYPE_BOOL,  &USE_CHARACTER_SET_TRANSLATION        },
-    {"file_character_set",                      CV_TYPE_STRING,&FILE_CHARACTER_SET                   },
-    {"user_character_set",                      CV_TYPE_STRING,&USER_CHARACTER_SET                   },
+    {"file_reading_character_set",              CV_TYPE_STRING,&FILE_READING_CHARACTER_SET                   },
+    {"file_writing_character_set",              CV_TYPE_STRING,&FILE_WRITING_CHARACTER_SET                   },
 
     {"message_box_position_none",               CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_NONE            },
     {"message_box_position_center",             CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_CENTER          },
@@ -328,6 +329,7 @@ void Init_Config_Variables (void)
     FILENAME_EXTENSION_LOWER_CASE            = 1;
     FILENAME_EXTENSION_UPPER_CASE            = 0;
     FILENAME_EXTENSION_NO_CHANGE             = 0;
+    PRESERVE_MODIFICATION_TIME               = 0;
     DATE_AUTO_COMPLETION                     = 1;
     NUMBER_TRACK_FORMATED                    = 1;
     NUMBER_TRACK_FORMATED_SPIN_BUTTON        = 2;
@@ -336,8 +338,8 @@ void Init_Config_Variables (void)
     SORTING_FILE_CASE_SENSITIVE              = 0;
     USE_ISO_8859_1_CHARACTER_SET_TRANSLATION = 1;
     USE_CHARACTER_SET_TRANSLATION            = 0;
-    FILE_CHARACTER_SET                       = g_strdup("ISO-8859-15");
-    USER_CHARACTER_SET                       = g_strdup("UTF-8");
+    FILE_READING_CHARACTER_SET               = g_strdup("UTF-8");
+    FILE_WRITING_CHARACTER_SET               = g_strdup("ISO-8859-15");
 
     MESSAGE_BOX_POSITION_NONE                = 0;
     MESSAGE_BOX_POSITION_CENTER              = 1;
@@ -473,7 +475,7 @@ void Apply_Changes (void)
          */
         /* Common */
         LOAD_ON_STARTUP               = GTK_TOGGLE_BUTTON(LoadOnStartup)->active;
-        DEFAULT_PATH_TO_MP3           = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(DefaultPathToMp3)->child)));
+        DEFAULT_PATH_TO_MP3           = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(DefaultPathToMp3)->child))); // Saved in UTF-8
         WRITE_ID3V1_TAG               = GTK_TOGGLE_BUTTON(WriteId3v1Tag)->active;
         WRITE_ID3V2_TAG               = GTK_TOGGLE_BUTTON(WriteId3v2Tag)->active;
         WRITE_ID3_TAGS_IN_FLAC_FILE   = GTK_TOGGLE_BUTTON(WriteId3TagsInFlacFiles)->active;
@@ -509,6 +511,7 @@ void Apply_Changes (void)
         FILENAME_EXTENSION_LOWER_CASE          = GTK_TOGGLE_BUTTON(FilenameExtensionLowerCase)->active;
         FILENAME_EXTENSION_UPPER_CASE          = GTK_TOGGLE_BUTTON(FilenameExtensionUpperCase)->active;
         FILENAME_EXTENSION_NO_CHANGE           = GTK_TOGGLE_BUTTON(FilenameExtensionNoChange)->active;
+        PRESERVE_MODIFICATION_TIME             = GTK_TOGGLE_BUTTON(PreserveModificationTime)->active;
         DATE_AUTO_COMPLETION                   = GTK_TOGGLE_BUTTON(DateAutoCompletion)->active;
         NUMBER_TRACK_FORMATED                  = GTK_TOGGLE_BUTTON(NumberTrackFormated)->active;
         NUMBER_TRACK_FORMATED_SPIN_BUTTON      = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(NumberTrackFormatedSpinButton));
@@ -519,12 +522,12 @@ void Apply_Changes (void)
         USE_CHARACTER_SET_TRANSLATION          = GTK_TOGGLE_BUTTON(UseCharacterSetTranslation)->active;
 
 
-        temp = Get_Active_Combo_Box_Item(GTK_COMBO_BOX(FileCharacterSetCombo));
-        FILE_CHARACTER_SET = Charset_Get_Name_From_Title(temp);
+        temp = Get_Active_Combo_Box_Item(GTK_COMBO_BOX(FileReadingCharacterSetCombo));
+        FILE_READING_CHARACTER_SET = Charset_Get_Name_From_Title(temp);
         g_free(temp);
 
-        temp = Get_Active_Combo_Box_Item(GTK_COMBO_BOX(UserCharacterSetCombo));
-        USER_CHARACTER_SET = Charset_Get_Name_From_Title(temp);
+        temp = Get_Active_Combo_Box_Item(GTK_COMBO_BOX(FileWritingCharacterSetCombo));
+        FILE_WRITING_CHARACTER_SET = Charset_Get_Name_From_Title(temp);
         g_free(temp);
 
         SORTING_FILE_MODE                      = gtk_combo_box_get_active(GTK_COMBO_BOX(SortingFileCombo));
